==> rolldice_1.8.orig.tar.gz: rolldice-1.8.orig/rolldice.h <==
/*
 * rolldice.h - v1.7 - 28 Mar 1999
 * (c) Stevie Strickland, 1999
 *
 * This program has been placed under the GPL.  Any bugfixes or enhancements
 * will be greatly appreciated :)
 *
 * Stevie Strickland - sstrickl@resnet.gatech.edu
 */

// Standard includes
#include <stdio.h>
#include <stdlib.h>

// For the time() function
#include <time.h>

// For the rand() and srand() functions
#include <math.h>

// For the strstr() function
#include <string.h>

// For some bounds
#include <values.h>

/* The following #defines give the position of each important dice-related
 * number inside of the dice_nums array.  The final #define gives us the
 * size of the dice_nums array, which should be the number of other 
 * #defines below.
 */
#define NUM_ROLLS 0
#define NUM_DICE 1
#define NUM_SIDES 2
#define MULTIPLIER 3
#define MODIFIER 4
#define NUM_DROP 5
#define DICE_ARRAY_SIZE 6

/* The following #defines give the tokens for each part of the format
 * string.  Perhaps eventually I'll change parse_string to use strtok()
 * instead of strstr() :)
 */
#define ROLL_IDENT "x"
#define DICE_SIDES_IDENT "d"
#define MULTI_IDENT "*"
#define MOD_PLUS_IDENT "+"
#define MOD_MINUS_IDENT "-"
#define DROP_IDENT "s"

// Defines values for true and false, just for testing stuff boolean-wise :)
#define TRUE_VAL 1
#define FALSE_VAL 0

// Defines values for the random number file to use
#define URANDOM 0
#define RANDOM 1

// External function declarations for using rolldice() and kin.
extern int *parse_string(char *dice_string);
extern int rolldie(int num_sides);
extern void init_random(int rand_file);

==> rolldice_1.10.orig.tar.gz: rolldice-1.10.orig/rolldice.h <==
/*
 * rolldice.h - v1.10 - 25 Nov 2001
 * (c) Stevie Strickland, 1999-2001
 *
 * This program has been placed under the GPL.  Any bugfixes or enhancements
 * will be greatly appreciated :)
 *
 * Stevie Strickland - sstrickl@cc.gatech.edu
 */

/* Standard includes */
#include <stdio.h>
#include <stdlib.h>

/* For GNU getopt */
#include <getopt.h>

/* For the time() function */
#include <time.h>

/* For the rand() and srand() functions */
#include <math.h>

/* For the strstr() function */
#include <string.h>

/* For some bounds */
#include <values.h>

/* The following #defines give the position of each important dice-related
 * number inside of the dice_nums array.  The final #define gives us the
 * size of the dice_nums array, which should be the number of other 
 * #defines below.
 */
#define NUM_ROLLS 0
#define NUM_DICE 1
#define NUM_SIDES 2
#define MULTIPLIER 3
#define MODIFIER 4
#define NUM_DROP 5
#define DICE_ARRAY_SIZE 6

/* The following #defines give the tokens for each part of the format
 * string.  Perhaps eventually I'll change parse_string to use strtok()
 * instead of strstr() :)
 */
#define ROLL_IDENT "x"
#define DICE_SIDES_IDENT "d"
#define MULTI_IDENT "*"
#define MOD_PLUS_IDENT "+"
#define MOD_MINUS_IDENT "-"
#define DROP_IDENT "s"

// Defines values for true and false, just for testing stuff boolean-wise :)
#define TRUE_VAL 1
#define FALSE_VAL 0

// Defines values for the random number file to use
typedef enum {UNDEF, URANDOM, RANDOM} rand_type;

// External function declarations for using rolldice() and kin.
extern int *parse_string(char *dice_string);
extern int rolldie(int num_sides);
extern void init_random(rand_type rand_file);
